/**
 * 权限校验逻辑
 * @param {Object} authorityString权限字符串
 */
function authorityCheck(authorityString) {
	var userInfoString = localStorage.getItem('ddh_userInfo');
	if(!userInfoString.trim()) {
		return false;
	}
	var userInfoObj = JSON.parse(userInfoString);
	if(!userInfoObj) {
		return false;
	}
	if(userInfoObj['IsAdmin']) {
		return true;
	}
	if(!authorityString.trim()) {
		return true;
	}
	var orAuthorityArray = authorityString.split('||');
	//处理or
	if(orAuthorityArray.length > 1) {
		var result = false;
		for(var i = 0; i < orAuthorityArray.length; i++) {
			result = (result || authorityCheck(orAuthorityArray[i]));
			//console.log('orAuthorityArray:' + authorityCheck(orAuthorityArray[i]) + ',result:' + result);
		}
		return result;
	}
	//处理and
	var andAuthorityArray = authorityString.split('&&');
	if(andAuthorityArray.length > 1) {
		var result = true;
		for(var i = 0; i < andAuthorityArray.length; i++) {
			result = result && authorityCheck(andAuthorityArray[i]);
			//console.log('andAuthorityArray:' +andAuthorityArray[i]+':'+authorityCheck(andAuthorityArray[i]) + ',result:' + result);
		}
		return result;
	}

	var permissionItemsArray = userInfoObj['PermissionItems'];
	if(!permissionItemsArray || permissionItemsArray.length == 0) {
		return false;
	}
	var authorityArray = authorityString.split('.'); //.分割权限
	if(authorityArray.length == 0) {
		return false;
	}
	//寻找模块top权限
	var targetLevel;
	for(var j = 0; j < permissionItemsArray.length; j++) {
		if(authorityArray[0] == permissionItemsArray[j].name) {
			targetLevel = permissionItemsArray[j];
			break;
		}
	}
	if(!targetLevel) {
		return false;
	}
	var targetAuthorityJSONObjArray = []; //对应top模块的所有权限列表
	/**
	 * 获取对应模块的所有权限列表：递归方法
	 * @param {Object} prefixString 前缀
	 * @param {Object} targetAuthorityJSONObj 权限对象
	 */
	function inGetModuleAuthorityArray(prefixString, targetAuthorityJSONObj) {
		var t = targetAuthorityJSONObj.items;
		if(targetAuthorityJSONObj && targetAuthorityJSONObj.actions) {
			prefixString += (targetAuthorityJSONObj.name + '.');
			for(var i = 0; i < targetAuthorityJSONObj.actions.length; i++) {
				if(targetAuthorityJSONObj.actions[i].enable) {
					var authorityName = prefixString + targetAuthorityJSONObj.actions[i].name
					targetAuthorityJSONObjArray.push(authorityName)
					//console.log(targetAuthorityJSONObj.text + '.' + targetAuthorityJSONObj.actions[i].text + "------" + authorityName);
				}
			}
		}
		if(t && t.length > 0) {
			for(i = 0; i < t.length; i++) {
				inGetModuleAuthorityArray(prefixString, t[i], targetAuthorityJSONObj.text);
			}
		}
	}
	inGetModuleAuthorityArray('', targetLevel);
	if(targetAuthorityJSONObjArray.indexOf(authorityString) == -1) {
		return false;
	}
	return true;
}
//执行权限检验
function excuteAuthorityCheck() {
	var hiddenDom = document.querySelectorAll('.app-hidden')
	var customerSoftVersion = JSON.parse(localStorage.getItem("ddh_userInfo"))["Version"];//客户软件版本
	for(var i = 0; i < hiddenDom.length; i++) {
		if(!hiddenDom[i].hasAttribute('data-permission')) {
			continue;
		}
		var permissionString = hiddenDom[i].getAttribute('data-permission')
		var specializeSoftVersion = hiddenDom[i].getAttribute('data-product-version');//应用指定的软件版本号
		if(authorityCheck(permissionString) && (!specializeSoftVersion || Number(specializeSoftVersion) ===customerSoftVersion)) {
			hiddenDom[i].classList.remove('app-hidden');
		} else {
			var _parentElement = hiddenDom[i].parentNode;
			if(_parentElement) {
				_parentElement.removeChild(hiddenDom[i]);
			}
		}
	}
}
//打印权限列表
//function printAuthList() {
//	var result =  "";
//	var userInfoString = localStorage.getItem('ddh_userInfo');
//	if(!userInfoString.trim()) {
//		return;
//	}
//	var userInfoObj = JSON.parse(userInfoString);
//	if(!userInfoObj) {
//		return;
//	}
//	var permissionItemsArray = userInfoObj['PermissionItems'];
//	if(!permissionItemsArray || permissionItemsArray.length == 0) {
//		return;
//	}
//	for(var j = 0; j < permissionItemsArray.length; j++) {
//		var targetLevel = permissionItemsArray[j];
//		var targetAuthorityJSONObjArray = []; //对应top模块的所有权限列表
//		/**
//		 * 获取对应模块的所有权限列表：递归方法
//		 * @param {Object} prefixString 前缀
//		 * @param {Object} targetAuthorityJSONObj 权限对象
//		 */
//		function inGetModuleAuthorityArray(prefixString, targetAuthorityJSONObj, prefixStringName) {
//			var t = targetAuthorityJSONObj.items;
//			if(targetAuthorityJSONObj && targetAuthorityJSONObj.actions) {
//				prefixString += (targetAuthorityJSONObj.name + '.');
//				for(var i = 0; i < targetAuthorityJSONObj.actions.length; i++) {
//					if(targetAuthorityJSONObj.actions[i].enable) {
//						var authorityName = prefixString + targetAuthorityJSONObj.actions[i].name
//						targetAuthorityJSONObjArray.push(authorityName)
//						result += (prefixStringName ? (prefixStringName + '.') : '') + targetAuthorityJSONObj.text + '.' + targetAuthorityJSONObj.actions[i].text + "------" + authorityName +"\n";
//					}
//				}
//			}
//			if(t && t.length > 0) {
//				for(i = 0; i < t.length; i++) {
//					inGetModuleAuthorityArray(prefixString, t[i], targetAuthorityJSONObj.text);
//				}
//			}
//		}
//		inGetModuleAuthorityArray('', targetLevel);
//	}
//
//	console.log(result);
//}
(function() {
	excuteAuthorityCheck();//页面引用之后立即执行校验
})();
